@@ -12,7 +12,8 @@ import (
 	"os/exec"
 	"slices"
 	"strings"
-	"syscall"
+
+	"golang.org/x/sys/unix"
 )
 
 var (
@@ -99,7 +100,7 @@ func main() {
 				Stdin:  os.Stdin,
 				Stdout: os.Stdout,
 				Stderr: os.Stderr,
-				SysProcAttr: &syscall.SysProcAttr{
+				SysProcAttr: &unix.SysProcAttr{
 					Setsid: true,
 				},
 			}
@@ -245,7 +246,7 @@ func chroot(dir string) {
 	if dir == "" {
 		return
 	}
-	if err := syscall.Chroot(dir); err != nil {
+	if err := unix.Chroot(dir); err != nil {
 		log.Fatalf("chroot failed: %v", err)
 	}
 }
